@@ -6,9 +6,9 @@ use Test::More ();
 use Test::Builder ();
 use Term::ANSIColor qw(colored);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
-our $BORDER_COLOR  = [qw|bright_cyan bold|];
+our $BORDER_COLOR  = [qw|cyan bold|];
 our $BORDER_CHAR   = '-';
 our $BORDER_LENGTH = 78;
 our $CAPTION_COLOR = ['clear'];
